@@ -15,7 +15,7 @@ class Page:
     Markdown files presented as Page objects
 
     Attributes:
-            title (str): <h1> has to use ==== not # markdown notation
+            title (str): <h1> using === or # heading markdown notation
             body (str): whatever follows h1
             slug (str): URL handle from filename without extension
             path (str): initial text file path
@@ -24,6 +24,7 @@ class Page:
             source (str): source folder (top level) used to determine top level pages
             author (str): extracted using "By **author name**" pattern right after heading
             ext (str): empty string, .htm or .html
+            home (bool): True for homepage
     """
     title: str
     body: str
@@ -34,6 +35,7 @@ class Page:
     source: str
     author: str = ''
     ext: str = ''
+    home: bool = False
 
     def __init__(self, path=None, source='', ext=''):
         if path:
@@ -41,8 +43,13 @@ class Page:
             self.source = source
             self.ext = ext
             content = open(path).read()
-            self.title = self.widont(content.split('\n===')[0])
-            self.md_body = content.split('===\n')[-1]
+            if content.startswith('#'):
+                self.title = content.split('\n')[0].replace('# ', '')
+                self.md_body = '\n'.join(content.split('\n')[1:])
+            else:
+                self.title = content.split('\n===')[0]
+                self.md_body = ''.join(content.split('===\n')[1:])
+            self.title = self.widont(self.title)
             self.body = markdown(self.md_body)
             self.author = ''
             if self.body.startswith('By **'):
@@ -57,6 +64,8 @@ class Page:
                 self.parent = None
             if self.parent == Path(self.source).stem:  # top level
                 self.parent = None
+            if self.slug == Path(self.source).stem and not self.parent:  # homepage
+                self.home = True
             self.created = dt.fromtimestamp(os.path.getctime(path))
 
     @staticmethod
@@ -80,12 +89,16 @@ class Page:
     def get_absolute_url(self):
         if self.parent:
             return f'/{self.parent}/{self.slug}{self.ext}'
-        else:
+        elif not self.home:
             return f'/{self.slug}{self.ext}'
+        else:
+            return '/'
 
     @property
     def teaser(self):
-        return self.body.split('\n\n***\n\n')[0]
+        if '***' in self.body:
+            return self.body.split('\n\n***\n\n')[0]
+        return self.body.split('\n\n')[0]
 
     @property
     def desc(self):
@@ -93,7 +106,7 @@ class Page:
         return meta_desc(s)
 
     def __str__(self):
-        return self.title
+        return self.get_absolute_url
 
     def __repr__(self):
         return self.get_absolute_url
